# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseRunExecutionCountInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'batch_count': 'int',
        'finished_count': 'int',
        'interactive_count': 'int',
        'total_count': 'int'
    }

    attribute_map = {
        'batch_count': 'batch_count',
        'finished_count': 'finished_count',
        'interactive_count': 'interactive_count',
        'total_count': 'total_count'
    }

    def __init__(self, batch_count=None, finished_count=None, interactive_count=None, total_count=None, local_vars_configuration=None):  # noqa: E501
        """ResponseRunExecutionCountInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._batch_count = None
        self._finished_count = None
        self._interactive_count = None
        self._total_count = None
        self.discriminator = None

        if batch_count is not None:
            self.batch_count = batch_count
        if finished_count is not None:
            self.finished_count = finished_count
        if interactive_count is not None:
            self.interactive_count = interactive_count
        if total_count is not None:
            self.total_count = total_count

    @property
    def batch_count(self):
        """Gets the batch_count of this ResponseRunExecutionCountInfo.  # noqa: E501


        :return: The batch_count of this ResponseRunExecutionCountInfo.  # noqa: E501
        :rtype: int
        """
        return self._batch_count

    @batch_count.setter
    def batch_count(self, batch_count):
        """Sets the batch_count of this ResponseRunExecutionCountInfo.


        :param batch_count: The batch_count of this ResponseRunExecutionCountInfo.  # noqa: E501
        :type batch_count: int
        """

        self._batch_count = batch_count

    @property
    def finished_count(self):
        """Gets the finished_count of this ResponseRunExecutionCountInfo.  # noqa: E501


        :return: The finished_count of this ResponseRunExecutionCountInfo.  # noqa: E501
        :rtype: int
        """
        return self._finished_count

    @finished_count.setter
    def finished_count(self, finished_count):
        """Sets the finished_count of this ResponseRunExecutionCountInfo.


        :param finished_count: The finished_count of this ResponseRunExecutionCountInfo.  # noqa: E501
        :type finished_count: int
        """

        self._finished_count = finished_count

    @property
    def interactive_count(self):
        """Gets the interactive_count of this ResponseRunExecutionCountInfo.  # noqa: E501


        :return: The interactive_count of this ResponseRunExecutionCountInfo.  # noqa: E501
        :rtype: int
        """
        return self._interactive_count

    @interactive_count.setter
    def interactive_count(self, interactive_count):
        """Sets the interactive_count of this ResponseRunExecutionCountInfo.


        :param interactive_count: The interactive_count of this ResponseRunExecutionCountInfo.  # noqa: E501
        :type interactive_count: int
        """

        self._interactive_count = interactive_count

    @property
    def total_count(self):
        """Gets the total_count of this ResponseRunExecutionCountInfo.  # noqa: E501


        :return: The total_count of this ResponseRunExecutionCountInfo.  # noqa: E501
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ResponseRunExecutionCountInfo.


        :param total_count: The total_count of this ResponseRunExecutionCountInfo.  # noqa: E501
        :type total_count: int
        """

        self._total_count = total_count

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseRunExecutionCountInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseRunExecutionCountInfo):
            return True

        return self.to_dict() != other.to_dict()
