# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmRunExecutionEdges(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_token': 'OrmAccessToken',
        'artifacts': 'list[OrmArtifact]',
        'created_by': 'OrmUser',
        'local_experiment': 'OrmExperiment',
        'organization': 'OrmOrganization',
        'pipeline_step_execution': 'OrmPipelineStepExecution',
        'plot_files': 'list[OrmPlotFile]',
        'project': 'OrmProject',
        'run_spec': 'OrmRunSpec',
        'tags': 'list[OrmTag]',
        'volumes': 'list[OrmVolume]',
        'workload': 'OrmWorkload'
    }

    attribute_map = {
        'access_token': 'access_token',
        'artifacts': 'artifacts',
        'created_by': 'created_by',
        'local_experiment': 'local_experiment',
        'organization': 'organization',
        'pipeline_step_execution': 'pipeline_step_execution',
        'plot_files': 'plot_files',
        'project': 'project',
        'run_spec': 'run_spec',
        'tags': 'tags',
        'volumes': 'volumes',
        'workload': 'workload'
    }

    def __init__(self, access_token=None, artifacts=None, created_by=None, local_experiment=None, organization=None, pipeline_step_execution=None, plot_files=None, project=None, run_spec=None, tags=None, volumes=None, workload=None, local_vars_configuration=None):  # noqa: E501
        """OrmRunExecutionEdges - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._access_token = None
        self._artifacts = None
        self._created_by = None
        self._local_experiment = None
        self._organization = None
        self._pipeline_step_execution = None
        self._plot_files = None
        self._project = None
        self._run_spec = None
        self._tags = None
        self._volumes = None
        self._workload = None
        self.discriminator = None

        if access_token is not None:
            self.access_token = access_token
        if artifacts is not None:
            self.artifacts = artifacts
        if created_by is not None:
            self.created_by = created_by
        if local_experiment is not None:
            self.local_experiment = local_experiment
        if organization is not None:
            self.organization = organization
        if pipeline_step_execution is not None:
            self.pipeline_step_execution = pipeline_step_execution
        if plot_files is not None:
            self.plot_files = plot_files
        if project is not None:
            self.project = project
        if run_spec is not None:
            self.run_spec = run_spec
        if tags is not None:
            self.tags = tags
        if volumes is not None:
            self.volumes = volumes
        if workload is not None:
            self.workload = workload

    @property
    def access_token(self):
        """Gets the access_token of this OrmRunExecutionEdges.  # noqa: E501


        :return: The access_token of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmAccessToken
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this OrmRunExecutionEdges.


        :param access_token: The access_token of this OrmRunExecutionEdges.  # noqa: E501
        :type access_token: OrmAccessToken
        """

        self._access_token = access_token

    @property
    def artifacts(self):
        """Gets the artifacts of this OrmRunExecutionEdges.  # noqa: E501


        :return: The artifacts of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: list[OrmArtifact]
        """
        return self._artifacts

    @artifacts.setter
    def artifacts(self, artifacts):
        """Sets the artifacts of this OrmRunExecutionEdges.


        :param artifacts: The artifacts of this OrmRunExecutionEdges.  # noqa: E501
        :type artifacts: list[OrmArtifact]
        """

        self._artifacts = artifacts

    @property
    def created_by(self):
        """Gets the created_by of this OrmRunExecutionEdges.  # noqa: E501


        :return: The created_by of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmUser
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this OrmRunExecutionEdges.


        :param created_by: The created_by of this OrmRunExecutionEdges.  # noqa: E501
        :type created_by: OrmUser
        """

        self._created_by = created_by

    @property
    def local_experiment(self):
        """Gets the local_experiment of this OrmRunExecutionEdges.  # noqa: E501


        :return: The local_experiment of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmExperiment
        """
        return self._local_experiment

    @local_experiment.setter
    def local_experiment(self, local_experiment):
        """Sets the local_experiment of this OrmRunExecutionEdges.


        :param local_experiment: The local_experiment of this OrmRunExecutionEdges.  # noqa: E501
        :type local_experiment: OrmExperiment
        """

        self._local_experiment = local_experiment

    @property
    def organization(self):
        """Gets the organization of this OrmRunExecutionEdges.  # noqa: E501


        :return: The organization of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this OrmRunExecutionEdges.


        :param organization: The organization of this OrmRunExecutionEdges.  # noqa: E501
        :type organization: OrmOrganization
        """

        self._organization = organization

    @property
    def pipeline_step_execution(self):
        """Gets the pipeline_step_execution of this OrmRunExecutionEdges.  # noqa: E501


        :return: The pipeline_step_execution of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmPipelineStepExecution
        """
        return self._pipeline_step_execution

    @pipeline_step_execution.setter
    def pipeline_step_execution(self, pipeline_step_execution):
        """Sets the pipeline_step_execution of this OrmRunExecutionEdges.


        :param pipeline_step_execution: The pipeline_step_execution of this OrmRunExecutionEdges.  # noqa: E501
        :type pipeline_step_execution: OrmPipelineStepExecution
        """

        self._pipeline_step_execution = pipeline_step_execution

    @property
    def plot_files(self):
        """Gets the plot_files of this OrmRunExecutionEdges.  # noqa: E501


        :return: The plot_files of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: list[OrmPlotFile]
        """
        return self._plot_files

    @plot_files.setter
    def plot_files(self, plot_files):
        """Sets the plot_files of this OrmRunExecutionEdges.


        :param plot_files: The plot_files of this OrmRunExecutionEdges.  # noqa: E501
        :type plot_files: list[OrmPlotFile]
        """

        self._plot_files = plot_files

    @property
    def project(self):
        """Gets the project of this OrmRunExecutionEdges.  # noqa: E501


        :return: The project of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmProject
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this OrmRunExecutionEdges.


        :param project: The project of this OrmRunExecutionEdges.  # noqa: E501
        :type project: OrmProject
        """

        self._project = project

    @property
    def run_spec(self):
        """Gets the run_spec of this OrmRunExecutionEdges.  # noqa: E501


        :return: The run_spec of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmRunSpec
        """
        return self._run_spec

    @run_spec.setter
    def run_spec(self, run_spec):
        """Sets the run_spec of this OrmRunExecutionEdges.


        :param run_spec: The run_spec of this OrmRunExecutionEdges.  # noqa: E501
        :type run_spec: OrmRunSpec
        """

        self._run_spec = run_spec

    @property
    def tags(self):
        """Gets the tags of this OrmRunExecutionEdges.  # noqa: E501


        :return: The tags of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: list[OrmTag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this OrmRunExecutionEdges.


        :param tags: The tags of this OrmRunExecutionEdges.  # noqa: E501
        :type tags: list[OrmTag]
        """

        self._tags = tags

    @property
    def volumes(self):
        """Gets the volumes of this OrmRunExecutionEdges.  # noqa: E501


        :return: The volumes of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: list[OrmVolume]
        """
        return self._volumes

    @volumes.setter
    def volumes(self, volumes):
        """Sets the volumes of this OrmRunExecutionEdges.


        :param volumes: The volumes of this OrmRunExecutionEdges.  # noqa: E501
        :type volumes: list[OrmVolume]
        """

        self._volumes = volumes

    @property
    def workload(self):
        """Gets the workload of this OrmRunExecutionEdges.  # noqa: E501


        :return: The workload of this OrmRunExecutionEdges.  # noqa: E501
        :rtype: OrmWorkload
        """
        return self._workload

    @workload.setter
    def workload(self, workload):
        """Sets the workload of this OrmRunExecutionEdges.


        :param workload: The workload of this OrmRunExecutionEdges.  # noqa: E501
        :type workload: OrmWorkload
        """

        self._workload = workload

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmRunExecutionEdges):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmRunExecutionEdges):
            return True

        return self.to_dict() != other.to_dict()
